@@ -101,14 +101,14 @@ solution_statistics <- function(x, solution) {
   out <- tibble::as_tibble(cbind(out, stats::setNames(as.data.frame(
     rcpp_funded_projects(
       x$pa_matrix(),
-      methods::as(as.matrix(solution[, x$action_names()]), "dgCMatrix"))),
+      as_Matrix(as.matrix(solution[, x$action_names()]), "dgCMatrix"))),
     x$project_names())))
   # add in columns for feature persistences
   out <- tibble::as_tibble(cbind(out, stats::setNames(as.data.frame(
     rcpp_expected_persistences(
       x$pa_matrix(), x$epf_matrix(),
-      methods::as(diag(x$number_of_features()), "dgCMatrix"),
-      methods::as(as.matrix(solution[, x$action_names()]), "dgCMatrix"))),
+      as_Matrix(diag(x$number_of_features()), "dgCMatrix"),
+      as_Matrix(as.matrix(solution[, x$action_names()]), "dgCMatrix"))),
       x$feature_names())))
   # return output
   out
